==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementEJB/src/com/clustercontrol/jobmanagement/util/SendQueue.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.util;

import java.util.Properties;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.jobmanagement.message.RunResultInfo;

/**
 * Queue饹
 *
 * @version 2.1.0
 * @since 1.0.0
 */
public class SendQueue {
    protected static Log m_log = LogFactory.getLog( SendQueue.class );
    
    protected String m_queueName;
    protected QueueConnectionFactory m_connectionFactory;
    protected QueueConnection m_connection;
    protected Queue m_queue;
    protected QueueSession m_session;
    
    /**
     * 󥹥ȥ饯
     * 
     * @param queueName
     * @throws NamingException
     * @throws JMSException
     */
    public SendQueue(String queueName) throws NamingException, JMSException{
        m_queueName = queueName;
    }
    
    /**
     * å
     * 
     * @param info
     * @throws JMSException
     * @throws NamingException
     */
    public void put(RunResultInfo info) throws JMSException, NamingException {
    	InitialContext context = null;
    	QueueSender sender = null;
    	try{
	    	//Queueν
			String serverName = System.getProperty("jboss.server.name");
			if(serverName.equals("all")){
				Properties properties = new Properties(); 
				properties.put(InitialContext.INITIAL_CONTEXT_FACTORY,"org.jnp.interfaces.NamingContextFactory");
				properties.put(InitialContext.URL_PKG_PREFIXES,"org.jboss.naming:org.jnp.interfaces");
				properties.put(InitialContext.PROVIDER_URL,"jnp://localhost:1100");
				
				context = new InitialContext(properties);
			}
			else{
				context = new InitialContext();
			}
	        m_connectionFactory = (QueueConnectionFactory)context.lookup("ConnectionFactory");
	        m_connection = m_connectionFactory.createQueueConnection();
	        m_session = m_connection.createQueueSession( false, Session.AUTO_ACKNOWLEDGE );
	        m_connection.start();
	        m_queue = (Queue)context.lookup(m_queueName);
	        sender = m_session.createSender(m_queue);
	        
	        //å
	        ObjectMessage message = m_session.createObjectMessage(info);
	        
	        //å
	        sender.send(message);
	        m_log.debug("put() send: SessionId = " + info.getSessionId() + ", JobId = " + info.getJobId() + ", FacilityId = " + info.getFacilityId() + ", status = " + info.getStatus() + ", CommandType = " + info.getCommandType());
	    }
		catch(NamingException e){
			throw e;
		}
		catch(JMSException e){
			throw e;
		}
		finally{
			try {
				if (context != null)
					context.close();
			}
			catch (NamingException e) {
			}
			
			try {
				if (sender != null){
					sender.close();
					sender = null;
				}
			}
			catch (JMSException e) {
			}
			
			try {
				if (m_session != null){
					m_session.close();
					m_session = null;
				}
			}
			catch (JMSException e) {
			}
	
			try {
				if (m_connection != null){
					m_connection.close();
					m_connection = null;
				}
			}
			catch (JMSException e){
			}
		}
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementEJB/src/com/clustercontrol/jobmanagement/util/SendQueue.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.util;

import java.util.Properties;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.jobmanagement.message.RunResultInfo;

/**
 * キューへメッセージを送信するクラスです。
 *
 * @version 2.1.0
 * @since 1.0.0
 */
public class SendQueue {
	/** ログ出力のインスタンス */
	protected static Log m_log = LogFactory.getLog( SendQueue.class );
    
	/** キュー名。 */
	protected String m_queueName;
	/** コネクションファクトリー。 */
	protected QueueConnectionFactory m_connectionFactory;
	/** コネクション。 */
	protected QueueConnection m_connection;
	/** キュー。 */
	protected Queue m_queue;
	/** セッション。 */
	protected QueueSession m_session;
    
    /**
     * コンストラクタ。<BR>
     * キュー名を設定します。
     * 
     * @param queueName キュー名
     * @throws NamingException
     * @throws JMSException
     */
    public SendQueue(String queueName) throws NamingException, JMSException{
        m_queueName = queueName;
    }
    
    /**
     * 引数で指定されたメッセージをキューへ送信します。
     * 
     * @param info 実行結果情報
     * @throws JMSException
     * @throws NamingException
     */
    public void put(RunResultInfo info) throws JMSException, NamingException {
    	InitialContext context = null;
    	QueueSender sender = null;
    	try{
	    	//Queueへ送信の初期化処理
			String serverName = System.getProperty("jboss.server.name");
			if(serverName.equals("all")){
				Properties properties = new Properties(); 
				properties.put(InitialContext.INITIAL_CONTEXT_FACTORY,"org.jnp.interfaces.NamingContextFactory");
				properties.put(InitialContext.URL_PKG_PREFIXES,"org.jboss.naming:org.jnp.interfaces");
				properties.put(InitialContext.PROVIDER_URL,"jnp://localhost:1100");
				
				context = new InitialContext(properties);
			}
			else{
				context = new InitialContext();
			}
	        m_connectionFactory = (QueueConnectionFactory)context.lookup("ConnectionFactory");
	        m_connection = m_connectionFactory.createQueueConnection();
	        m_session = m_connection.createQueueSession( false, Session.AUTO_ACKNOWLEDGE );
	        m_connection.start();
	        m_queue = (Queue)context.lookup(m_queueName);
	        sender = m_session.createSender(m_queue);
	        
	        //送信メッセージ作成
	        ObjectMessage message = m_session.createObjectMessage(info);
	        
	        //メッセージ送信
	        sender.send(message);
	        m_log.debug("put() send: SessionId = " + info.getSessionId() + ", JobId = " + info.getJobId() + ", FacilityId = " + info.getFacilityId() + ", status = " + info.getStatus() + ", CommandType = " + info.getCommandType());
	    }
		catch(NamingException e){
			throw e;
		}
		catch(JMSException e){
			throw e;
		}
		finally{
			try {
				if (context != null)
					context.close();
			}
			catch (NamingException e) {
			}
			
			try {
				if (sender != null){
					sender.close();
					sender = null;
				}
			}
			catch (JMSException e) {
			}
			
			try {
				if (m_session != null){
					m_session.close();
					m_session = null;
				}
			}
			catch (JMSException e) {
			}
	
			try {
				if (m_connection != null){
					m_connection.close();
					m_connection = null;
				}
			}
			catch (JMSException e){
			}
		}
    }
}
